@@ -8,8 +8,8 @@ import re
 def create_cmd_parser(subparsers):
     parser_recolor = subparsers.add_parser(
         'frosted', help='frosted glass on a pic')
-    parser_recolor.add_argument("-f",
-                                "--file",
+    parser_recolor.add_argument("-i",
+                                "--infile",
                                 help="the file to be frosted")
     parser_recolor.add_argument("-s",
                                 "--size",
@@ -25,7 +25,7 @@ def repeat2(str_tobe_repeat):
 
 def _on_args_parsed(args):
     params = vars(args)
-    filename = params['file']
+    filename = params['infile']
     sizeStr = params['size']
     if not sizeStr:
         sizeStr = '10'
