@@ -27,8 +27,8 @@ def create_cmd_parser(subparsers):
     parser_resize = subparsers.add_parser(
         'resize', help='resize a pic',
     )
-    parser_resize.add_argument("-f",
-                               "--file",
+    parser_resize.add_argument("-i",
+                               "--infile",
                                help="The file to be resize")
     parser_resize.add_argument("-o",
                                "--outfile",
@@ -48,7 +48,7 @@ def create_cmd_parser(subparsers):
 def _on_args_parsed(args):
     params = vars(args)
     app = params['app']
-    infile = params['file']
+    infile = params['infile']
     outfile = params['outfile']
     size = params['size']
 
